ExprLoweringContext

Struct ExprLoweringContext 

pub struct ExprLoweringContext<'a> {
    pub owner: &'a DagId,
    pub resolver: &'a ModuleResolver,
    pub generic_scope: &'a GenericScope,
    pub prelude: Option<&'a PreludeTypeScope>,
    pub decl_bindings: Option<&'a HashMap<ScopedName, ResolvedName<Decl>>>,
}
Context required to lower one expression tree into HIR.

Fields

owner: &'a DagIdresolver: &'a ModuleResolvergeneric_scope: &'a GenericScopeprelude: Option<&'a PreludeTypeScope>decl_bindings: Option<&'a HashMap<ScopedName, ResolvedName<Decl>>>

Implementations

Source

impl<'a> ExprLoweringContext<'a>

pub const fn new( owner: &'a DagId, resolver: &'a ModuleResolver, generic_scope: &'a GenericScope, ) -> Self

Create an expression-lowering context.

pub const fn with_prelude(self, prelude: &'a PreludeTypeScope) -> Self

Add implicit prelude type symbols for lowering type arguments.

pub const fn with_decl_bindings( self, decl_bindings: &'a HashMap<ScopedName, ResolvedName<Decl>>, ) -> Self

Add canonical declaration bindings for declarations already visible in the lowered IR, such as prefixed dependency entries and DAG self-imports.