pub enum HirLowerError {
ModuleResolve {
source: ModuleResolveError,
span: Span,
},
UnknownTypePath {
path: String,
span: Span,
},
GenericConstraintMismatch {
name: GenericParamName,
actual: GenericConstraint,
expected: &'static str,
span: Span,
},
UnknownGenericParam {
name: GenericParamName,
span: Span,
},
DuplicateGenericParam {
name: GenericParamName,
first: Span,
duplicate: Span,
},
WrongDatetimeArgCount {
got: usize,
span: Span,
},
ExpectedTimeScaleName {
span: Span,
},
UnknownTimeScale {
name: String,
expected: &'static str,
span: Span,
},
}Expand description
Errors produced while lowering syntax type expressions into HIR.
Variants
ModuleResolve
A module-aware lookup failed at the use site.
UnknownTypePath
A type-level path was not found in any namespace valid for that syntax position.
GenericConstraintMismatch
A natural-number expression referenced a non-Nat generic parameter.
UnknownGenericParam
A natural-number expression referenced a name that is not a generic parameter.
DuplicateGenericParam
A generic parameter list declared the same name twice.
WrongDatetimeArgCount
Datetime<...> has the wrong number of arguments.
ExpectedTimeScaleName
Datetime<...> argument was not a bare time-scale name.
UnknownTimeScale
Datetime<...> argument was a bare name, but not a supported time scale.