pub struct DimExprItem {
pub op: MulDivOp,
pub term: DimTermRef,
}Expand description
One term of a dimension expression with its combining operator.
Fields
op: MulDivOpterm: DimTermRefTrait Implementations
Sourceimpl Clone for DimExprItem
impl Clone for DimExprItem
Sourcefn clone(&self) -> DimExprItem
fn clone(&self) -> DimExprItem
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DimExprItem
impl Debug for DimExprItem
impl Eq for DimExprItem
Sourceimpl PartialEq for DimExprItem
impl PartialEq for DimExprItem
Sourcefn eq(&self, other: &DimExprItem) -> bool
fn eq(&self, other: &DimExprItem) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for DimExprItem