pub enum IndexTypeRef {
Declared(TypeNameRef<Index>),
NatRange(NatRangeIndexRef),
}Expand description
Type-level reference to an index definition.
Declared indexes are owner-qualified names. Compiler-generated range(N)
axes are typed Nat-range identities and do not have declared resolved names.
Variants
Declared(TypeNameRef<Index>)
NatRange(NatRangeIndexRef)
Implementations
Sourceimpl IndexTypeRef
impl IndexTypeRef
Sourcepub fn from_resolved(resolved: ResolvedName<Index>) -> Self
pub fn from_resolved(resolved: ResolvedName<Index>) -> Self
Create a module-aware reference from a canonical resolved declared-index name.
Sourcepub fn with_owner(owner: DagId, name: NameDef<Index>) -> Self
pub fn with_owner(owner: DagId, name: NameDef<Index>) -> Self
Resolve a declared-index definition-site leaf into the given owner.
Sourcepub const fn with_display_leaf(
name: NameDef<Index>,
resolved: ResolvedName<Index>,
) -> Self
pub const fn with_display_leaf( name: NameDef<Index>, resolved: ResolvedName<Index>, ) -> Self
Create a reference with a display leaf that differs from the canonical owner-qualified identity.
Sourcepub const fn from_nat_range(index: NatRangeIndex) -> Self
pub const fn from_nat_range(index: NatRangeIndex) -> Self
Create a concrete compiler-generated Nat range reference.
Sourcepub fn from_nat_range_form(
form: NatPolyForm,
) -> Result<Self, NatRangeIndexError>
pub fn from_nat_range_form( form: NatPolyForm, ) -> Result<Self, NatRangeIndexError>
Create a Nat range reference from a normalized Nat form.
Errors
Returns an error when the form is a concrete invalid Nat range size.
Sourcepub const fn from_nat_range_ref(reference: NatRangeIndexRef) -> Self
pub const fn from_nat_range_ref(reference: NatRangeIndexRef) -> Self
Wrap an already validated Nat range reference.
Sourcepub const fn declared_name(&self) -> Option<&NameDef<Index>>
pub const fn declared_name(&self) -> Option<&NameDef<Index>>
The declared leaf name, when this is a declared index.
Sourcepub const fn declared_resolved(&self) -> Option<&ResolvedName<Index>>
pub const fn declared_resolved(&self) -> Option<&ResolvedName<Index>>
The canonical declared owner/name identity, when this is a declared index.
Sourcepub const fn nat_range_ref(&self) -> Option<&NatRangeIndexRef>
pub const fn nat_range_ref(&self) -> Option<&NatRangeIndexRef>
Return the Nat range reference, when this is a compiler-generated Nat range.
Sourcepub const fn nat_range(&self) -> Option<NatRangeIndex>
pub const fn nat_range(&self) -> Option<NatRangeIndex>
Return the typed concrete Nat range identity, if this reference has one.
Sourcepub fn nat_range_form(&self) -> Option<NatPolyForm>
pub fn nat_range_form(&self) -> Option<NatPolyForm>
Return the normalized Nat form, when this is a Nat range reference.
Sourcepub fn display_name(&self) -> NameDef<Index>
pub fn display_name(&self) -> NameDef<Index>
Render a display-only leaf name for diagnostics and formatting.
Sourcepub fn matches_ref(&self, other: &Self) -> bool
pub fn matches_ref(&self, other: &Self) -> bool
Compare this reference against another type reference.
Sourcepub fn to_unowned_name(&self) -> NameDef<Index>
pub fn to_unowned_name(&self) -> NameDef<Index>
Clone the leaf definition/display name for diagnostic/display boundaries.