pub struct DimDecl {
pub visibility: BindableVisibility,
pub name: Spanned<DimName>,
pub definition: Option<DimExpr>,
}Expand description
Dimension declaration with a body or required.
Two forms:
- Derived:
dim Velocity = Length / Time;—definition: Some(...) - Required:
dim D;—definition: None. The library requires a dimension to be bound here from outside (via an include with dim bindings). Treated like an opaque base dimension when the library is compiled standalone.
Fields
visibility: BindableVisibilityname: Spanned<DimName>definition: Option<DimExpr>Trait Implementations
Sourceimpl FormatEquivalent for DimDecl
impl FormatEquivalent for DimDecl
Sourcefn format_equivalent(&self, other: &Self) -> bool
fn format_equivalent(&self, other: &Self) -> bool
Returns
true if self and other are equivalent up to formatting.Auto Trait Implementations
impl Freeze for DimDecl
impl RefUnwindSafe for DimDecl
impl Send for DimDecl
impl Sync for DimDecl
impl Unpin for DimDecl
impl UnsafeUnpin for DimDecl
impl UnwindSafe for DimDecl