pub struct DimExprItem {
pub op: MulDivOp,
pub term: DimTerm,
}Expand description
One term in a dimension expression with its combining operator.
Fields
op: MulDivOpMul for the first term and for *, Div for /.
term: DimTermTrait Implementations
Sourceimpl Clone for DimExprItem
impl Clone for DimExprItem
Sourcefn clone(&self) -> DimExprItem
fn clone(&self) -> DimExprItem
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DimExprItem
impl Debug for DimExprItem
Sourceimpl FormatEquivalent for DimExprItem
impl FormatEquivalent for DimExprItem
Sourcefn format_equivalent(&self, other: &Self) -> bool
fn format_equivalent(&self, other: &Self) -> bool
Returns
true if self and other are equivalent up to formatting.Auto Trait Implementations
impl Freeze for DimExprItem
impl RefUnwindSafe for DimExprItem
impl Send for DimExprItem
impl Sync for DimExprItem
impl Unpin for DimExprItem
impl UnsafeUnpin for DimExprItem
impl UnwindSafe for DimExprItem