pub struct PlotDecl<P: Phase = Raw> {
pub visibility: Visibility,
pub name: Spanned<DeclName>,
pub mark: MarkSpec<P>,
pub encodings: Vec<Encoding<P>>,
pub properties: Vec<PlotField<P>>,
}Expand description
Plot declaration: plot name = { mark: point, encode: { x: ..., y: ... }, title: "..." };
Plots are leaf declarations that depend on params/nodes via @-references.
They produce a plot specification, not a runtime Value.
Fields
visibility: Visibilityname: Spanned<DeclName>mark: MarkSpec<P>encodings: Vec<Encoding<P>>properties: Vec<PlotField<P>>Trait Implementations
Sourceimpl FormatEquivalent for PlotDecl
impl FormatEquivalent for PlotDecl
Sourcefn format_equivalent(&self, other: &Self) -> bool
fn format_equivalent(&self, other: &Self) -> bool
Returns
true if self and other are equivalent up to formatting.Auto Trait Implementations
impl<P> Freeze for PlotDecl<P>
impl<P> RefUnwindSafe for PlotDecl<P>
impl<P> Send for PlotDecl<P>
impl<P> Sync for PlotDecl<P>
impl<P> Unpin for PlotDecl<P>
impl<P> UnsafeUnpin for PlotDecl<P>
impl<P> UnwindSafe for PlotDecl<P>