pub struct PlotField<P: Phase = Raw> {
pub name: Spanned<PlotPropertyName>,
pub value: Expr<P>,
pub span: Span,
}Expand description
A named field in a plot or figure declaration body.
Example: title: "My Chart"
Fields
name: Spanned<PlotPropertyName>The field name (e.g., “title”, “width”, “height”).
value: Expr<P>The field value expression.
span: SpanTrait Implementations
Sourceimpl FormatEquivalent for PlotField
impl FormatEquivalent for PlotField
Sourcefn format_equivalent(&self, other: &Self) -> bool
fn format_equivalent(&self, other: &Self) -> bool
Returns
true if self and other are equivalent up to formatting.Auto Trait Implementations
impl<P> Freeze for PlotField<P>
impl<P> RefUnwindSafe for PlotField<P>
impl<P> Send for PlotField<P>
impl<P> Sync for PlotField<P>
impl<P> Unpin for PlotField<P>
impl<P> UnsafeUnpin for PlotField<P>
impl<P> UnwindSafe for PlotField<P>