pub struct BlankLine { /* private fields */ }Expand description
A blank line represented by the span from the previous line ending through the line ending that completes the blank line.
Implementations