pub struct Dimension { /* private fields */ }Expand description
A physical dimension represented as a sparse vector of rational exponents over base dimensions.
For example, Velocity = Length^1 * Time^-1 is represented as
{BaseDimId::Prelude("Length"): 1, BaseDimId::Prelude("Time"): -1}.
Only non-zero exponents are stored. An empty map represents the dimensionless dimension.
Implementations
Sourceimpl Dimension
impl Dimension
Sourcepub const fn dimensionless() -> Self
pub const fn dimensionless() -> Self
The dimensionless dimension (empty exponent map).
pub fn is_dimensionless(&self) -> bool
Sourcepub fn get_exponent(&self, id: &BaseDimId) -> Rational
pub fn get_exponent(&self, id: &BaseDimId) -> Rational
Get the exponent for a specific base dimension (zero if absent).
Sourcepub fn iter(&self) -> impl Iterator<Item = (&BaseDimId, &Rational)>
pub fn iter(&self) -> impl Iterator<Item = (&BaseDimId, &Rational)>
Returns an iterator over the non-zero (BaseDimId, Rational) pairs.
Sourcepub fn pow(&self, exp: Rational) -> Result<Self, RationalError>
pub fn pow(&self, exp: Rational) -> Result<Self, RationalError>
Raise a dimension to a rational power (multiply all exponents).
Returns Err(RationalError::Overflow) if any exponent multiplication
produces a reduced value outside the i32 range.
Sourcepub fn pow_int(&self, n: i32) -> Result<Self, RationalError>
pub fn pow_int(&self, n: i32) -> Result<Self, RationalError>
Raise a dimension to an integer power.
Returns Err(RationalError::Overflow) if any exponent multiplication
overflows i32.
Sourcepub const fn display_with<'a>(
&'a self,
names: &'a BTreeMap<BaseDimId, String>,
) -> DimensionDisplay<'a>
pub const fn display_with<'a>( &'a self, names: &'a BTreeMap<BaseDimId, String>, ) -> DimensionDisplay<'a>
Format this dimension using named base dimensions for display.
The names map provides BaseDimId → name mappings.
Unknown IDs are displayed as D{id}.