pub struct ModuleIndexSymbol { /* private fields */ }Expand description
Index symbol plus the variants declared by that index.
Implementations
Sourceimpl ModuleIndexSymbol
impl ModuleIndexSymbol
Sourcepub const fn resolved(&self) -> &ResolvedName<Index>
pub const fn resolved(&self) -> &ResolvedName<Index>
Canonical resolved identity for the index type.
Sourcepub const fn visibility(&self) -> SymbolVisibility
pub const fn visibility(&self) -> SymbolVisibility
Visibility of the index declaration.
Sourcepub const fn variants(&self) -> &HashMap<IndexVariantName, Span>
pub const fn variants(&self) -> &HashMap<IndexVariantName, Span>
Variant names declared by this index, keyed by leaf name.