pub struct QualifiedIndexVariantName { /* private fields */ }Expand description
A fully qualified index variant name, rendered as Index.Variant.
Implementations
Sourceimpl QualifiedIndexVariantName
impl QualifiedIndexVariantName
Sourcepub const fn new(index: IndexName, variant: IndexVariantName) -> Self
pub const fn new(index: IndexName, variant: IndexVariantName) -> Self
Create a qualified index variant name from its index and variant parts.
Sourcepub const fn variant(&self) -> &IndexVariantName
pub const fn variant(&self) -> &IndexVariantName
The variant/constructor part of the qualified variant.