pub type DeclName = NameDef<Decl>;Expand description
Name of a const, param, or node declaration (e.g., "G0", "dry_mass", "dv_total").
Aliased Type
pub struct DeclName { /* private fields */ }Trait Implementations
Sourceimpl FormatEquivalent for DeclName
impl FormatEquivalent for DeclName
Sourcefn format_equivalent(&self, other: &Self) -> bool
fn format_equivalent(&self, other: &Self) -> bool
Returns
true if self and other are equivalent up to formatting.