pub type ModuleAliasName = NameDef<ModuleAlias>;Expand description
Name of a module alias introduced by an import/include declaration (e.g., "constants", "std").
Aliased Type
pub struct ModuleAliasName { /* private fields */ }Trait Implementations
Sourceimpl FormatEquivalent for ModuleAliasName
impl FormatEquivalent for ModuleAliasName
Sourcefn format_equivalent(&self, other: &Self) -> bool
fn format_equivalent(&self, other: &Self) -> bool
Returns
true if self and other are equivalent up to formatting.