pub enum ModuleResolveError {
DuplicateModule {
owner: DagId,
},
UnknownModule {
owner: DagId,
},
UnknownModuleAlias {
owner: DagId,
alias: ModuleAliasName,
},
DuplicateSymbol {
owner: DagId,
namespace: &'static str,
name: String,
first: Span,
duplicate: Span,
},
DuplicateImportName {
owner: DagId,
namespace: &'static str,
name: String,
first: Span,
duplicate: Span,
},
UnknownName {
owner: DagId,
namespace: &'static str,
name: String,
},
WrongUniverseName {
owner: DagId,
name: String,
expected: SurfaceNameKind,
actual: SurfaceNameKind,
},
UnexpectedDeclKind {
name: ResolvedName<Decl>,
expected: &'static str,
actual: DeclSymbolKind,
},
PrivateName {
owner: DagId,
namespace: &'static str,
name: String,
},
ExpectedIndexVariantPath {
owner: DagId,
path: String,
},
UnknownIndexVariant {
index: ResolvedName<Index>,
variant: IndexVariantName,
},
AmbiguousIndexVariant {
owner: DagId,
variant: IndexVariantName,
indexes: Vec<ResolvedName<Index>>,
},
}Expand description
Errors produced while building or using module-aware symbol tables.
Variants
DuplicateModule
A module was added twice.
UnknownModule
No symbol table exists for a canonical module identity.
UnknownModuleAlias
A module qualifier’s first segment is not an alias in the current module.
DuplicateSymbol
Duplicate definition in one namespace.
DuplicateImportName
Duplicate local import/alias in one namespace.
UnknownName
A name was not found in the requested namespace.
WrongUniverseName
A name exists, but in a semantic universe that is not valid here.
UnexpectedDeclKind
A name exists but has the wrong declaration kind for the use site.
PrivateName
A name exists but is not public across module boundaries.
ExpectedIndexVariantPath
A path did not have enough segments to denote Index.Variant.
UnknownIndexVariant
The index exists, but the requested variant is absent.
AmbiguousIndexVariant
A bare variant exists on more than one visible index.