pub trait NameNamespace:
Debug
+ Clone
+ Copy
+ PartialEq
+ Eq
+ Hash
+ PartialOrd
+ Ord
+ 'static {
const DISPLAY_NAME: &'static str;
}Expand description
Marker trait for a semantic name namespace.
Namespaces are zero-sized marker types used by NameDef and
ResolvedName to make it impossible to mix, for example, a function name
with an index name. The marker’s NameNamespace::DISPLAY_NAME is used
only for diagnostics and panic messages at construction boundaries.
Required Associated Constants
Sourceconst DISPLAY_NAME: &'static str
const DISPLAY_NAME: &'static str
Human-readable alias/newtype name for this namespace.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".