pub enum InferredType {
Scalar(Dimension),
Bool,
Int,
Fin(NatLinearForm),
Datetime(TimeScale),
NamedIndex(InferredIndex),
Struct(InferredStructType, Vec<Self>),
Indexed {
element: Box<Self>,
index: InferredIndex,
},
}Expand description
The inferred type of an expression.
Variants
Scalar(Dimension)
Bool
Int
Fin(NatLinearForm)
A bounded natural number Fin(N): the type of loop variables over range(N).
A value of type Fin(N) satisfies 0 <= value < N. This enables compile-time
bounds checking: v[i] is valid when i : Fin(N) and v : T[M] with N <= M.
Fin(N) is not a user-declarable type — it only arises as the type of loop
variables in for i: range(N) { ... }.
Datetime(TimeScale)
A datetime instant in a specific time scale.
NamedIndex(InferredIndex)
A named index identity in an index-only position.
This is used for named-index loop variables and Index generic
arguments. It is intentionally not a Graphcal value type.
Struct(InferredStructType, Vec<Self>)
A struct type, optionally with concrete type arguments for generic structs.
Indexed
Implementations
Sourceimpl InferredType
impl InferredType
Sourcepub const fn is_int_like(&self) -> bool
pub const fn is_int_like(&self) -> bool
Returns true if this type is Int or Fin(N) (integer-like).