pub struct InferredIndex { /* private fields */ }Expand description
Index identity carried by inferred collection/label types.
Declared indexes compare by owner-qualified IndexTypeRef. Nat-range
indexes additionally carry their normalized Nat form so generic ranges such
as range(N + 1) are not encoded in or compared through synthetic strings.
Implementations
Sourceimpl InferredIndex
impl InferredIndex
pub fn with_owner(owner: DagId, name: IndexName) -> Self
pub fn from_resolved(resolved: ResolvedName<Index>) -> Self
pub const fn from_ref(reference: IndexTypeRef) -> Self
Sourcepub fn from_nat_range_identity(
identity: &NatRangeIndexIdentity,
) -> Result<Self, NatRangeIndexError>
pub fn from_nat_range_identity( identity: &NatRangeIndexIdentity, ) -> Result<Self, NatRangeIndexError>
Create an inferred Nat range index from a validated Nat-range identity.
Errors
Returns an error if the identity cannot be converted to an index type reference.
Sourcepub fn from_nat_range_form(
form: NatLinearForm,
) -> Result<Self, NatRangeIndexError>
pub fn from_nat_range_form( form: NatLinearForm, ) -> Result<Self, NatRangeIndexError>
Create an inferred Nat range index from a normalized Nat form.
Errors
Returns an error when the form is a concrete invalid Nat range size.
pub const fn type_ref(&self) -> &IndexTypeRef
pub fn name(&self) -> IndexName
pub const fn declared_resolved(&self) -> Option<&ResolvedName<Index>>
pub const fn concrete_nat_range(&self) -> Option<NatRangeIndex>
pub fn nat_range_form(&self) -> Option<NatLinearForm>
pub fn matches_resolved(&self, expected: &ResolvedName<Index>) -> bool
pub fn matches_ref(&self, expected: &IndexTypeRef) -> bool